//=====================================================================================
//
// Project: 
// Constant-time bilateral filter
// 
// Authors: 
// Daniel Sage, Kunal N. Chaudhury
// Biomedical Imaging Group (BIG)
// Ecole Polytechnique Federale de Lausanne (EPFL)
// Lausanne, Switzerland
//
// Date:
// 4 February 2011
//
// Reference:
// Kunal N. Chaudhury, Daniel Sage, and Michael Unser,
// Fast O(1) bilateral filtering using trigonometric range kernels
// IEEE Transactions on Image Processing, submitted Dec. 2010
//
// Conditions of use:
// You'll be free to use this software for research purposes, but you
// should not redistribute it without our consent. In addition, we 
// expect you to include a citation or acknowledgment whenever 
// you present or publish results that are based on it.
//
//=====================================================================================

import ij.Macro;
import ij.plugin.PlugIn;
import bilateralfiltergui.MainDialog;

public class Bilateral_Filter_Instant implements PlugIn  {

	public void run(String arg) {
		MainDialog dlg = new MainDialog();
		
		if (Macro.getOptions() == null) {
			dlg.doDialog();
		}
		else {
			String options = Macro.getOptions();
			float sigRange = Float.parseFloat(Macro.getValue(options, "sigma_range", "100"));
			float sigmaX = Float.parseFloat(Macro.getValue(options, "sigma_space", "10"));
			float sigmaY = Float.parseFloat(Macro.getValue(options, "anisotropy_xy", "1")) * sigmaX;
			float sigmaZ = Float.parseFloat(Macro.getValue(options, "anisotropy_xz", "1")) * sigmaX;
			int modeIteration = Integer.parseInt(Macro.getValue(options, "iteration_mode", "0"));
			int nbIteration = Integer.parseInt(Macro.getValue(options, "iteration_nb", "1"));
			int methodSelectionChannels = Integer.parseInt(Macro.getValue(options, "method", "0"));
			double valueSelectionChannels = Double.parseDouble(Macro.getValue(options, "value", "0"));
			boolean multithread = Boolean.parseBoolean(Macro.getValue(options, "multithread", "true"));
			boolean log = Boolean.parseBoolean(Macro.getValue(options, "log", "true"));

			dlg.process(sigRange, sigmaX, sigmaY, sigmaZ, methodSelectionChannels, valueSelectionChannels,
					modeIteration, nbIteration, multithread, log);
		}
	}
		

}
