//=====================================================================================
//
// Project: 
// Constant-time bilateral filter
// 
// Authors: 
// Daniel Sage, Kunal N. Chaudhury
// Biomedical Imaging Group (BIG)
// Ecole Polytechnique Federale de Lausanne (EPFL)
// Lausanne, Switzerland
//
// Date:
// 4 February 2011
//
// Reference:
// Kunal N. Chaudhury, Daniel Sage, and Michael Unser,
// Fast O(1) bilateral filtering using trigonometric range kernels
// IEEE Transactions on Image Processing, submitted Dec. 2010
//
// Conditions of use:
// You'll be free to use this software for research purposes, but you
// should not redistribute it without our consent. In addition, we 
// expect you to include a citation or acknowledgment whenever 
// you present or publish results that are based on it.
//
//=====================================================================================
package bilateralfiltergui;

import ij.ImagePlus;
import ij.gui.ImageCanvas;
import ij.process.ByteProcessor;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

public class AppletCanvas extends ImageCanvas implements MouseListener {
	
	private int nx;
	private int ny;
	private Color bgColor = new Color(200, 200, 0, 80);
	int xprev = -1;
	int yprev = -1;
	int imageSelected = 1;
	int imageUsed = 1;
	int featureSelected = 0;
	private BilateralFilterInstantApplet applet;
	private float sigSpace = 80;
	private float sigRange = 80;
	private ByteProcessor bp;
	
	public AppletCanvas(ImagePlus imp, ByteProcessor bp, BilateralFilterInstantApplet applet) {
   		super(imp);
   		this.bp = bp;
		nx = imp.getWidth();
		ny = imp.getHeight();
		this.addMouseListener(this);
		this.addMouseMotionListener(this);
		this.applet = applet;
		repaint();
	}

	public void paint(Graphics g) {
		super.paint(g);
		g.setColor(bgColor);
		g.fillRect(0, ny-20, nx, 20);
		//g.fillRect(0, 0, nx, 20);
		drawString(g, "Input image", 10, ny-6, Color.orange, 12);
		//drawString(g, "Bilateral Filter Instant.", 10, 12, Color.orange, 12);
		drawString(g, "  << ", 264, ny-6, Color.orange, 12);
		drawString(g, "  S: " + sigSpace, 264+30, ny-6, Color.orange, 12);
		drawString(g, "  >> ", 264+96, ny-6, Color.orange, 12);
		drawString(g, "  << ", 264+128, ny-6, Color.orange, 12);
		drawString(g, "  R: " + sigRange, 264+160, ny-6, Color.orange, 12);
		drawString(g, "  >> ", 264+224, ny-6, Color.orange, 12);
		g.setColor(Color.black);
		g.drawRect(264, ny-20-1, 264+32, ny-1-1);
		g.setColor(bgColor);
		g.drawRect(264, ny-20, 264+32, ny-1);
		g.drawRect(264+32, ny-20, 264+96, ny-1);	// space
		g.drawRect(264+96, ny-20, 264+128, ny-1);
		g.drawRect(264+128, ny-20, 264+160, ny-1);
		g.drawRect(264+160, ny-20, 264+224, ny-1);	// range
		g.drawRect(264+224, ny-20, 264+255, ny-1);
	}
		
	/**
	*/
	private void drawString(Graphics g, String msg, int x, int y, Color c, int size) {
		g.setFont(new Font("Arial", Font.PLAIN, size));
		g.setColor(new Color(33, 33, 33));
		g.drawString(msg, x+1, y+1);
		g.setColor(c);
		g.drawString(msg, x, y);
	}	
	/**
	*/
	public void mouseClicked(MouseEvent e)  {
		int y = e.getY();
		int x = e.getX();
		if (y < ny - 20)
			return;
		if (x < 256) {
			imageUsed++;
			if (imageUsed >= 3)
				imageUsed = 0;
			bp = applet.load(""+ imageUsed + ".jpg");
			applet.process(bp, sigSpace, sigRange);
			return;
		}
		if (x > 264 && x < 264+32) {
			sigSpace -= 5;
			sigSpace = Math.max(10, sigSpace);
		}
		if (x > 264+96 && x < 264+128) {
			sigSpace += 5;
			sigSpace = Math.min(200, sigSpace);
		}
		if (x > 264+128 && x < 264+160) {
			sigRange -= 5;
			sigRange = Math.max(10, sigRange);
		}
		if (x > 264+224 && x < 264+255) {
			sigRange += 5;
			sigRange = Math.min(200, sigRange);
		}
		applet.process(bp, sigSpace, sigRange);
		
		repaint();
	}
	
	public void mouseEntered(MouseEvent e)  { super.mouseEntered(e); }
	public void mouseExited(MouseEvent e)  	{ super.mouseExited(e); }
	public void mousePressed(MouseEvent e)  { super.mousePressed(e); }
	public void mouseReleased(MouseEvent e) { super.mouseReleased(e); }
		

}
