//=====================================================================================
//
// Project: 
// Constant-time bilateral filter
// 
// Authors: 
// Daniel Sage, Kunal N. Chaudhury
// Biomedical Imaging Group (BIG)
// Ecole Polytechnique Fdrale de Lausanne (EPFL)
// Lausanne, Switzerland
//
// Date:
// 4 February 2011
//
// Reference:
// Kunal N. Chaudhury, Daniel Sage, and Michale Unser,
// Fast O(1) bilateral filtering using trigonometric range kernels
// IEEE Transactions on Image Processing, submitted Dec. 2010
//
// Conditions of use:
// You'll be free to use this software for research purposes, but you
// should not redistribute it without our consent. In addition, we 
// expect you to include a citation or acknowledgment whenever 
// you present or publish results that are based on it.
//
//=====================================================================================
package bilateralfiltergui;

import ij.ImagePlus;
import ij.gui.ImageWindow;
import ij.process.ByteProcessor;
import ij.process.FloatProcessor;

import java.applet.Applet;
import java.awt.Dimension;
import java.awt.Image;
import java.awt.MediaTracker;
import java.awt.Toolkit;
import java.net.URL;

import bilateralfilterinstant.Data;
import bilateralfilterinstant.Filter;

public class BilateralFilterInstantApplet extends Applet {

	private ImagePlus imp;
	
	/**
	*/
	public void init() {
		ByteProcessor bp = load("1.jpg");
		center(imp);
		AppletCanvas canvas  = new AppletCanvas(imp, bp, this);	 	
		imp.setWindow(new ImageWindow(imp, canvas));
		canvas.repaint();
		process(bp, 10, 60);
	}
	
	/**
	*/
	private void center(ImagePlus imp) {		
		Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		Dimension window = imp.getWindow().getSize();
		if (window.width==0)
			return;
		int left = screen.width/4-window.width/2;
		int top = (screen.height-window.height)/4;
		if (top<0) top = 0;
		imp.getWindow().setLocation(left, top);
	}

	/**
	*/
	public void process(ByteProcessor bp, float sigSpace, float sigRange) {
		int nx = bp.getWidth();
		Filter filter = new Filter(sigRange, sigSpace, sigSpace, 0);
		Data input = new Data(new ImagePlus("",bp));
		float[] out = filter.execute(null, input, 0);
		FloatProcessor fp = (FloatProcessor)imp.getProcessor();
		for(int i=0; i<256; i++)
		for(int j=0; j<256; j++)
			fp.putPixelValue(i+264, j, out[i+j*nx]);
		imp.updateAndDraw();
	}
	
	/**
	*/
	public ByteProcessor load(String filename) {
		ByteProcessor bp = (ByteProcessor)((new ImagePlus("", loadImageFile(filename))).getProcessor());
		if (imp == null) {
			FloatProcessor fp = new FloatProcessor(520, 256);
			for(int i=0; i<256; i++)
			for(int j=0; j<256; j++)
				fp.putPixelValue(i, j, bp.getPixelValue(i, j));
			imp = new ImagePlus("Bilateral Filter Instant", fp);
			imp.show();
		}
		else {
			FloatProcessor fp = (FloatProcessor)imp.getProcessor();
			for(int i=0; i<256; i++)
			for(int j=0; j<256; j++)
				fp.putPixelValue(i, j, bp.getPixelValue(i, j));
			imp.updateAndDraw();
		}
		return bp;
	}
	
	/**
	*/
	public Image loadImageURL(String urltext) {
		Image image = null;
		try {
			URL url = new URL(urltext);
			MediaTracker mtracker = new MediaTracker(this);
			image = getImage(url);
			mtracker.addImage(image, 0);
			mtracker.waitForAll();
		}
		catch  (Exception e) {
			System.out.println("Exeception" + e);
		}
	 	return image;
	}
	
	/**
	*/
	public Image loadImageFile(String filename) {
		Image image=null;
		MediaTracker mtracker = new MediaTracker(this);
		image = getImage(this.getDocumentBase(), filename);
		mtracker.addImage(image, 0);
	   	try {
			mtracker.waitForAll();
	   	} 
	   	catch (InterruptedException ie) {
			System.out.println("Bad loading of an image.");
	   	}
	 	return image;
	}
	
}
