//=====================================================================================
//
// Project: 
// Constant-time bilateral filter
// 
// Authors: 
// Daniel Sage, Kunal N. Chaudhury
// Biomedical Imaging Group (BIG)
// Ecole Polytechnique Federale de Lausanne (EPFL)
// Lausanne, Switzerland
//
// Date:
// 4 February 2011
//
// Reference:
// Kunal N. Chaudhury, Daniel Sage, and Michael Unser,
// Fast O(1) bilateral filtering using trigonometric range kernels
// IEEE Transactions on Image Processing, submitted Dec. 2010
//
// Conditions of use:
// You'll be free to use this software for research purposes, but you
// should not redistribute it without our consent. In addition, we 
// expect you to include a citation or acknowledgment whenever 
// you present or publish results that are based on it.
//
//=====================================================================================
package bilateralfiltergui;

import ij.IJ;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;

public class FilterCanvas extends Canvas {
	
	private float[] gaussian;
	private float[] approx;
	private float[] quality;
	
	private int h = 100;
	private int w = 200;
	
	/**
	 * 
	 */
	public FilterCanvas() {
		setBackground(Color.WHITE);
	}
	
	/**
	 * 
	 */
	public Dimension getPreferredSize() {
		return new Dimension(w, h);
	}
	
	/**
	 * 
	 */
	public void setCurves(float[] gaussian, float[] approx, float[] quality) {
		this.gaussian = gaussian;
		this.approx = approx;
		this.quality = quality;
		repaint();
	}
	
	/**
	 * 
	 */
	public void paint(Graphics g) {
		g.setColor(Color.GRAY);
		g.drawLine(0, 0, 0, h);
		g.drawLine(0, 0, w, 0);
		g.drawLine(0, h-1, w, h-1);
		g.drawLine(w-1, 0, w-1, h);
				 
		if (gaussian== null || approx == null) {
			setBackground(Color.BLACK);
			return;
		}
		
		setBackground(Color.WHITE);
		int origin = 3*h/4;
		//g.drawLine(0, origin, w, origin);
		//g.drawLine(0, top, w, top);

		if (gaussian != null) {
			g.setColor(Color.BLUE);
			int n = gaussian.length;
			for(int i=0; i<n-1; i++) {
				int x1 = (int)Math.round((1.0*i)/n * w);
				int x2 = (int)Math.round((1.0*(i+1))/n * w);
				int y1 = origin-(int)Math.round(gaussian[i] * 0.70 * h);
				int y2 = origin-(int)Math.round(gaussian[i+1] * 0.70 * h);
				g.drawLine(x1, y1, x2, y2);
			}
		}
		
		if (approx != null) {
			g.setColor(Color.RED);
			int n = approx.length;
			for(int i=0; i<n-1; i++) {
				int x1 = (int)Math.round((1.0*i)/n * w);
				int x2 = (int)Math.round((1.0*(i+1))/n * w);
				int y1 = origin-(int)Math.round(approx[i] * 0.70* h);
				int y2 = origin-(int)Math.round(approx[i+1] * 0.70* h);
				g.drawLine(x1, y1, x2, y2);
			}
		}
		
		if (quality != null) {
			g.setColor(new Color(200, 150, 20, 100));
			g.fillRect(0, 0, w, 15);
			g.fillRect(0, h-15, w, 15);
			g.setColor(Color.BLACK);
			g.drawString("Attenuation:" + IJ.d2s(quality[2]*100, 1) + " %", 2, 13);
			g.drawString("Undershoot :" + IJ.d2s(quality[1]*100, 1) + " %", 2, h-2);
		}
			
	}
}
